@@ -26,9 +26,7 @@
 #include <QHash>
 #include "libkdepimakonadi_private_export.h"
 
-namespace KPIM
-{
-
+namespace KPIM {
 class LIBKDEPIMAKONADI_TESTS_EXPORT BlackListBalooEmailListItem : public QListWidgetItem
 {
 public:
@@ -56,9 +54,9 @@ public:
     void setExcludeDomain(const QStringList &domain);
     int setEmailFound(const QStringList &);
 protected:
-    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent *event) override;
 
-    void changeEvent(QEvent *event) Q_DECL_OVERRIDE;
+    void changeEvent(QEvent *event) override;
 
 private:
     void generalPaletteChanged();
